"""
SQLAlchemy-boolean-search
========
SQLAlchemy-boolean-search translates a boolean search expression such as::

    field1=*something* and not (field2==1 or field3<=10.0)

into its corresponding SQLAlchemy filter.

Install
--------
::

    pip install sqlalchemy-boolean-search


Usage example
--------
::

    from sqlalchemy_boolean_search import parse_boolean_search

    # DataModel defined elsewhere (with field1, field2 and field3)
    from app.models import DataModel

    # Parse boolean search into a parsed expression
    boolean_search = 'field1=*something* and not (field2==1 or field3<=10.0)'
    parsed_expression = parse_boolean_search(boolean_search)

    # Retrieve records using a filter generated by the parsed expression
    records = DataModel.query.filter(parse_expression.filter(DataModel))

Documentation
-------------
`SQLAlchemy-boolean-search Documentation <http://sqlalchemy-boolean-search.readthedocs.org/>`_

"""

from setuptools import setup

setup(
    name='SQLAlchemy-boolean-search',
    version='0.1.0',
    url='http://github.com/lingthio/SQLAlchemy-boolean-search',
    license='BSD License',
    author='Ling Thio',
    author_email='ling.thio@gmail.com',
    description='Boolean search expression parser for SQLAlchemy',
    long_description=__doc__,
    keywords='Boolean search Flask SQLAlchemy',
    py_modules=['sqlalchemy_boolean_search'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'Flask',
        'Flask-SQLAlchemy',
        'pyparsing',
    ],
    test_suite="flask_user.tests.run_tests",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Flask',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Database :: Front-Ends',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
